void setup() {
  // --- Сброс/Восстановление настроек -------------------------------------------------------------------------
#if (KEEP_SETTINGS)
  if (EEPROM.read(101) != 101) {                // Если в 101 ячейке не 101 - сбрасываем настройки.
    EEPROM.write(101, 101);
    updateEEPROM();
  } else {                                      // Если нет - считываем настройки
    readEEPROM();
  }
#if (EEPROM_LOW_PASS)                           // Восстановить значения шумов из памяти
    LOW_PASS_mic = EEPROM.readInt(36);
    SPEKTR_LOW_PASS_mic = EEPROM.readInt(32);
    LOW_PASS_line = EEPROM.readInt(38);
    SPEKTR_LOW_PASS_line = EEPROM.readInt(34);
    MAX_COEF_FREQ_mic = EEPROM.readFloat(50);
    MAX_COEF_FREQ_line = EEPROM.readFloat(54);
#endif
#endif
  //============================================================================================================

#if (SETTINGS_LOG)
  Serial.begin(9600); // Запустить монитор порта
#endif
  
  /*
    TypicalSMD5050 =0xFFB0F0,
    typical values for SMD5050 LEDs

    Typical8mmPixel =0xFFE08C
    typical values for 8mm "pixels on a string" also for many through-hole 'T' package LEDs

    TypicalLEDStrip =0xFFB0F0
    TypicalPixelString =0xFFE08C

    UncorrectedColor =0xFFFFFF
    uncorrected color
  */
  FastLED.addLeds<WS2811, LED_PIN, GRB>(leds, NUM_LEDS).setCorrection(0xFFB0D0);    // setCorrection - каллибрует оттенок цвета (что бы белый был БЕЛЫМ). Выше есть стандартные варианты, я подгонял вручную под свою ленту.
  if (CURRENT_LIMIT > 0) FastLED.setMaxPowerInVoltsAndMilliamps(5, CURRENT_LIMIT);

  pinMode(POT_GND, OUTPUT);
  digitalWrite(POT_GND, LOW);

  IRLremote.begin(IR_PIN);

#if (SCHEM == 0 && LED_INDICATE)
  pinMode(LED_ON, OUTPUT); pinMode(LED_OFF, OUTPUT); pinMode(LED_line, OUTPUT);
#endif

#if (SCHEM == 0)
  pinMode(RELAYon, OUTPUT);
#endif

#if (LED_INDICATE)
  pinMode(LED_IR, OUTPUT);
#endif

#if (SCHEM == 0 && LED_INDICATE)
  for (byte i = 0; i < 3; i++) {  //Помигаем светодиодами на передней панели
    digitalWrite(LED_OFF, HIGH); delay(100); digitalWrite(LED_OFF, LOW); delay(100);
    digitalWrite(LED_ON, HIGH); delay(100); digitalWrite(LED_ON, LOW); delay(100);
    digitalWrite(LED_line, HIGH); delay(100); digitalWrite(LED_line, LOW); delay(100);
#if (LED_INDICATE)
    digitalWrite(LED_IR, HIGH); delay(100); digitalWrite(LED_IR, LOW); delay(100);
#endif
  }
  digitalWrite(LED_OFF, HIGH); digitalWrite(LED_ON, LOW);
#if (LED_INDICATE)
  digitalWrite(LED_IR, LOW);
#endif
#endif

  // для увеличения точности уменьшаем опорное напряжение,
  // выставив EXTERNAL и подключив Aref к выходу 3.3V на плате через делитель
  // GND ---[10-20 кОм] --- REF --- [10 кОм] --- 3V3
  // в данной схеме GND берётся из А0 для удобства подключения
  if (POTENT) analogReference(EXTERNAL);
  else        analogReference(INTERNAL);

  // меняем частоту оцифровки до 18 кГц
  // поднимаем частоту опроса аналогового порта до 38.4 кГц, по теореме
  // Котельникова (Найквиста) частота дискретизации будет 19.2 кГц
  // http://yaab-arduino.blogspot.ru/2015/02/fast-sampling-from-analog-input.html
  sbi(ADCSRA, ADPS2);
  cbi(ADCSRA, ADPS1);
  sbi(ADCSRA, ADPS0);
}
